@@ -302,15 +302,3 @@ rename_transformed_pars <- function(pars, transformations) {
   }
   return(pars)
 }
-
-# for plots that are ggplot objects arranged with gridExtra
-as_bayesplot_grid <- function(x) {
-  structure(x, class = unique(c("bayesplot_grid", class(x))))
-}
-
-#' @export
-print.bayesplot_grid <- function(x, ...) {
-  gridExtra::grid.arrange(x, ...)
-}
-#' @export
-plot.bayesplot_grid <- print.bayesplot_grid
