@@ -25,13 +25,25 @@
 #' @param facet_args Arguments (other than \code{facets}) passed to
 #'   \code{\link[ggplot2]{facet_wrap}} to control faceting.
 #' @param ... Currently ignored.
-#'
+#' @param divergences For models fit using \code{\link{NUTS}} (more generally,
+#'   any \href{http://en.wikipedia.org/wiki/Symplectic_integrator}{symplectic
+#'   integrator}), an optional vector or data frame providing information about
+#'   divergent transitions. If a data frame is provided it should be an object
+#'   returned by \code{\link{nuts_params}} (or an object with the same
+#'   structure). If a vector is provided it should be a vector with one element
+#'   per iteration, with each element either \code{0} (no divergence) or
+#'   \code{1} (a divergence in at least one chain). If \code{divergences} is
+#'   specified then red tick marks are added to the bottom of the traceplot
+#'   indicating within which iterations there was a divergence. See the end of
+#'   the \strong{Examples} section, below.
 #' @template return-ggplot
 #'
 #' @section Plot Descriptions:
 #' \describe{
 #'   \item{\code{mcmc_trace}}{
-#'    Standard traceplots of MCMC draws.
+#'    Standard traceplots of MCMC draws. For models fit using \code{\link{NUTS}}
+#'    the \code{divergences} argument can be used to also show divergences on
+#'    the traceplot.
 #'   }
 #'   \item{\code{mcmc_trace_highlight}}{
 #'    Traces are plotted using points rather than lines and the opacity of all
@@ -74,10 +86,26 @@
 #' # mark first 100 draws as warmup
 #' mcmc_trace(x, n_warmup = 100)
 #'
-#'
 #' # plot as points, highlighting chain 2
 #' color_scheme_set("brightblue")
 #' mcmc_trace_highlight(x, pars = "sigma", highlight = 2, size = 2)
+#'
+#' # for models fit using NUTS divergences can be displayed in the traceplot
+#' library("rstanarm")
+#' fit <- stan_glm(mpg ~ ., data = mtcars,
+#'   # next line to keep example fast and also ensure we get some divergences
+#'                 prior = hs(), iter = 400, adapt_delta = 0.8)
+#'
+#' # extract draws using as.array (instead of as.matrix) to keep
+#' # chains separate for traceplot
+#' posterior <- as.array(fit)
+#'
+#' # for stanfit and stanreg objects use nuts_params() to get the divergences
+#' mcmc_trace(
+#'   posterior,
+#'   pars = "sigma",
+#'   divergences = nuts_params(fit) # or nuts_params(fit, pars = "divergent__")
+#' )
 #' }
 #'
 NULL
@@ -93,7 +121,8 @@ mcmc_trace <-
            ...,
            n_warmup = 0,
            window = NULL,
-           size = NULL) {
+           size = NULL,
+           divergences = NULL) {
     check_ignored_arguments(...)
     .mcmc_trace(
       x,
@@ -105,6 +134,7 @@ mcmc_trace <-
       window = window,
       size = size,
       style = "line",
+      divergences = divergences,
       ...
     )
   }
@@ -144,6 +174,7 @@ mcmc_trace_highlight <-
 
 
 # internal -----------------------------------------------------------------
+#' @importFrom dplyr %>% filter_ group_by_ summarise_ select_
 .mcmc_trace <- function(x,
                        pars = character(),
                        regex_pars = character(),
@@ -155,6 +186,7 @@ mcmc_trace_highlight <-
                        highlight = NULL,
                        style = c("line", "point"),
                        alpha = 0.2,
+                       divergences = NULL,
                        ...) {
 
   style <- match.arg(style)
@@ -183,7 +215,8 @@ mcmc_trace_highlight <-
     mapping <- aes_(x = ~ Iteration, y = ~ Value, color = ~ Chain)
   } else {
     stopifnot(length(highlight) == 1)
-    mapping <- aes_(x = ~ Iteration, y = ~ Value,
+    mapping <- aes_(x = ~ Iteration,
+                    y = ~ Value,
                     alpha = ~ Chain == highlight,
                     color = ~ Chain == highlight)
   }
@@ -216,6 +249,15 @@ mcmc_trace_highlight <-
   } else {
     graph <- graph +
       scale_color_manual("Chain", values = chain_colors(n_chain))
+
+    if (!is.null(divergences))
+      graph <- graph +
+        divergence_rug(divergences, n_iter) +
+        guides(
+          color = guide_legend(order = 1),
+          linetype = guide_legend(order = 2, title = NULL, keywidth = rel(1/2),
+                                  override.aes = list(size = rel(1/2)))
+        )
   }
 
   facet_args$facets <- ~ Parameter
@@ -224,6 +266,7 @@ mcmc_trace_highlight <-
 
   graph +
     do.call("facet_wrap", facet_args) +
+    scale_x_continuous(breaks = pretty) +
     theme_default() +
     legend_move(ifelse(nlevels(data$Chain) > 1, "right", "none")) +
     xaxis_title(FALSE) +
@@ -244,3 +287,42 @@ chain_colors <- function(n) {
   )
   unname(rev(clrs))
 }
+
+
+# Add divergences to traceplot using geom_rug
+#
+# @param divergences User's 'divergences' argument, if specified
+# @param n_iter Number of iterations in the trace plot (to check against number
+#   of iterations provided in 'divergences')
+# @param color,size Passed to geom_rug.
+divergence_rug <- function(divergences, n_iter, color = "red", size = 1/4) {
+  if (is.data.frame(divergences)) {
+    divergences <- validate_nuts_data_frame(divergences)
+    stopifnot(length(unique(divergences$Iteration)) == n_iter)
+    div_info <-
+      filter_(divergences, ~ Parameter == "divergent__") %>%
+      group_by_(~ Iteration) %>%
+      summarise_(Divergent = ~ ifelse(sum(Value) > 0, Iteration, NA)) %>%
+      select_(~ Divergent)
+  } else {
+    stopifnot(
+      is_vector_or_1Darray(divergences),
+      length(divergences) == n_iter,
+      all(divergences %in% c(0, 1))
+    )
+    divergences <- ifelse(divergences == 1, seq_along(divergences), NA)
+    div_info <- data.frame(Divergent = divergences)
+  }
+  if (all(is.na(div_info$Divergent)))
+    message("No divergences to plot.")
+
+  geom_rug(
+    aes_(x = ~ Divergent, linetype = "Divergence"),
+    data = div_info,
+    na.rm = TRUE,
+    inherit.aes = FALSE,
+    sides = "b",
+    color = color,
+    size = size
+  )
+}
